# israwave

Mission to create a Hebrew TTS model as powerful and user-friendly as WaveNet

## Features

- Generate sentence in less than 1ms on CPU
- Powerful text processor by espeak-ng
- Support for SSML (soon)

## Samples

See example audio [here](https://github.com/thewh1teagle/israwave/releases/download/v0.1.0/israwave.wav)

## Examples

See [examples](examples)